Changelog
^^^^^^^^^^^^^^^^^^^^

1.1.0 (2016-02-14)
~~~~~~~~~~~~~~~~~~

This package was in need of some love and attention.

* Added Django 1.8, 1.9 and 1.10 support
* Added unit tests and coverage
* Make the project build with Travis
* Dropped Django 1.3, 1.4 support

1.0.3
~~~~~~~~~~~~~~~~~~
* Added tests and support for Django 1.7

1.0.2
~~~~~~~~~~~~~~~~~~
* Update to use the new url style in templates.
